@@ -66,9 +66,9 @@ class Commander:
         if config_file:
             if not get_real_path(config_file).is_file():
                 raise ConfigurationFileNotFoundError
-            self._config.config_file = get_real_path(config_file)
+            self._config = Config(get_real_path(config_file))
         elif config_file_list and config_file_list[0]:
-            self._config.config_file = config_file_list[0]
+            self._config = Config(config_file_list[0])
         if self._config.config_file and self._config.get('aria2'):
             aria2 = self._config.get('aria2')
         else:
@@ -83,7 +83,7 @@ class Commander:
             if not password:
                 raise InvalidPassword
             self._disk.login(username, password)
-        elif config_file_list:
+        elif self._config.config_file:
             refresh_token = self._config.get('refresh_token')
             username = self._config.get('username')
             password = self._config.get('password')
@@ -315,7 +315,7 @@ class Commander:
                     share_info = parse_share_url(path, self._disk.access_token)
                     file = self._path_list.get_path_node(share_info.name, update=False)
                     if file and not file.data.type:
-                        path = path.replace(share_info.name, share_info.name + str(int(time.time())))
+                        path = f'{self._share_link}{path.lstrip(self._share_link).split("|")[0]}_{str(int(time.time()))}|{path.split("|", 1)[1]}'
                         share_info = parse_share_url(path, self._disk.access_token)
                     if not self._path_list.get_path_fid(share_info.name, update=False):
                         self.upload_share(share_info)
@@ -528,6 +528,7 @@ class Commander:
                 else:
                     self._print.download_info(p)
                     self._print.print_line()
+                    self._path_list.update_path_list(file_node.id)
                     self.download_file(p, file_node.download_url, chunk_size)
                 self._print.print_line()
             else:
@@ -616,7 +617,7 @@ class Commander:
                     url = f'{self._share_link}{file.name}|{file.content_hash}|{url_base64}|{file.size}|{parent_file or "root"}'
                     share_txt += url + '\n'
                     share_txt += '导入链接'.center(50, '*') + '\n'
-                    share_txt += f'python main.py upload "{url}"' + '\n\n'
+                    share_txt += f'python aliyunpan.py upload "{url}"' + '\n\n'
                 print(share_txt)
                 GLOBAL_VAR.txt += share_txt
             else:
@@ -634,7 +635,7 @@ class Commander:
             with open(file_name, 'w', encoding='utf-8') as f:
                 f.write(GLOBAL_VAR.txt)
             print('文件导入'.center(50, '*'))
-            print(f'python main.py upload -s {file_name}')
+            print(f'python aliyunpan.py upload -s {file_name}')
             print('链接导入'.center(50, '*'))
             file_id = self.upload(file_name)[0]
             print()
@@ -643,7 +644,7 @@ class Commander:
                 file = self._path_list._tree.get_node(file_id).data
                 url_base64 = base64.b64encode(self.disk.get_download_url(file_id).encode()).decode()
                 url = f'{self._share_link}{Path(path).name}|{file.content_hash}|{url_base64}|{file.size}|root'
-                print(f'python main.py upload -s "{url}"')
+                print(f'python aliyunpan.py upload -s "{url}"')
 
     def tui(self):
         from aliyunpan.cli.tui import AliyunpanTUI
@@ -689,14 +690,14 @@ class Commander:
     def sync_local(self, sync_path, save_path, sync_time, chunk_size, delete, **kwargs):
         if not save_path:
             save_path = '.'
-        path = AliyunpanPath(save_path) + AliyunpanPath(sync_path)
+        path = AliyunpanPath(save_path) + AliyunpanPath(sync_path).name
         if not path.exists():
             self.download(sync_path, save_path)
         file_id = self.path_list.get_path_fid(sync_path, update=False)
         if not file_id:
             raise FileNotFoundError(sync_path)
         self._path_list.update_path_list(sync_path, is_fid=False)
-        path_ = self._path_list._tree.to_dict(file_id, with_data=True)[str(AliyunpanPath(sync_path))]
+        path_ = self._path_list._tree.to_dict(file_id, with_data=True)[str(AliyunpanPath(sync_path)).name]
         change_file_list = self._path_list.check_path_diff(path, path_['children'] if 'children' in path_ else [])
         for path_ in change_file_list:
             p = str(AliyunpanPath(path_) - AliyunpanPath(save_path))
